#! /bin/sh -xv
#
#+
# =================
# geomag_profile.sh
# =================
#
# -------------------------
# define GEOMAG environment
# -------------------------
#
# SYNOPSIS
# ========
#
# Online usage::
#
#  $ . geomag_profile.sh -d directory -i indir -o outdir -t tempdir
#
# In ${HOME}/.profile, add the following line::
#
#  . geomag_profile.sh -d directory  -i indir -o outdir -t tempdir
#
# DESCRIPTION
# ===========
#
# define GEOMAG environment
#
# ${GEOMAG} is the base directory of tools.
#
# ${GEOMAG_LOG} is the directory where log files  will be written.
#
# ${GEOMAG_ID} is the directory where input files must be.
#
# ${GEOMAG_OD} is the directory where output files will be written.
#
# MANPATH++
#
# EXAMPLES
# ========
#
# For fplod, on aedon.locean-ipsl.upmc.fr::
#
#  $ cd /usr/home/fplod/incas/geomag/geomag_ws
#  $ . geomag_profile.sh -d /usr/home/fplod/incas/geomag/geomag_ws/ -i ${HOME}/geomag_d/ -o ${HOME}/geomag_d/ -t /usr/temp/${LOGNAME}/log/
#
# For reee522 on rhodes.idris.fr::
#
#  $ cd ${HOME}/incas/geomag/geomag_ws/
#  $ . geomag_profile.sh -d ${HOME}/incas/geomag/geomag_ws/ -i ${HOMEGAYA}/geomag_d/ -o ${HOMEGAYA}/geomag_d/ -t /tmp/${LOGNAME}/log/
#
# TODO
# ====
#
# ++ option bavarde
#
# ++ machine dependant
#
# ++ besoin de posix
#
# ++ pas de MANPATH defini par dfaut sur zeus
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 20100318T073619Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * unset
#
# - reee522 2007-06-14T14:25:00Z rhodes (IRIX64)
#
#   * add -i, -o and -t parameters to be more flexible
#   * some bug fixes
#   * more checking
#
# - fplod 2007-03-13T16:12:41Z zeus.locean-ipsl.upmc.fr (Linux)
#
#   * add creation of $GEOMAG_ID and $GEOMAG_OD if they don't exist
#
# - reee522 2006-11-23T11:41:41Z rhodes (IRIX64)
#
#   * pas de set -o posix sur rhodes (IRIX64)
#
# - fplod 2006-03-22T10:13:38Z aedon.lodyc.jussieu.fr (Darwin)
#
#   * creation
#
#-
#
command=geomag_profile.sh
#
usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir"
#
set +u
while [ ! -z "${1}" ] # ++ pb bash
do
 case ${1} in
 -d) # directory for application choosen by user (see svn checkout command used)
  directory=${2}
  shift
 ;;
 -i) # directory for inputs choosen by user
  indir=${2}
  shift
 ;;
 -o) # directory for outputs choosen by user
  outdir=${2}
  shift
 ;;
 -t) # directory for temporary outputs choosen by user
  tempdir=${2}
  shift
 ;;

 *) # other choice
  echo "eee : unknown option ${1}"
  echo "${usage}"
  # nb : no exit because this file should be launched by login process
 ;;
 esac
 shift # next flag
done
unset usage
#
set -u
#
# check for ${directory}
if [ ! -d ${directory} ]
then
 echo " eee : ${directory} not found"
 # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
 echo " eee : ${directory} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
set -u
system=$(uname)
case "${system}" in
IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
unset system
#
GEOMAG=${directory}
export GEOMAG
unset directory
#
# add GEOMAG tools to PATH
# if not already done
echo ${PATH} | grep -q ${GEOMAG}
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${GEOMAG}/:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${GEOMAG}/ already in \${PATH}"
fi
unset test_path
#
# add GEOMAG manuals to MANPATH
# if not already done
echo ${MANPATH} | grep -q ${GEOMAG}
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${GEOMAG}/doc/manuals/man/:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${GEOMAG}/doc/manuals/man/ already in \${MANPATH}"
fi
unset test_manpath
#
GEOMAG_LOG=${tempdir}
export GEOMAG_LOG
unset tempdir
if [ ! -d ${GEOMAG_LOG} ]
then
  mkdir -p ${GEOMAG_LOG}
  echo "${command} : iii : creation of \${GEOMAG_LOG}"
fi
# check for permission on GEOMAG_LOG
if [ ! -x ${GEOMAG_LOG} ]
then
 echo " eee : ${GEOMAG_LOG} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
# check for permission on GEOMAG_LOG
if [ ! -w ${GEOMAG_LOG} ]
then
 echo " eee : ${GEOMAG_LOG} not writable"
 # nb : no exit because this file shouldreachable be launched by login process
fi
#
EDITOR=vi
export EDITOR
#
# io directories
GEOMAG_ID=${indir}
export GEOMAG_ID
unset indir
if [ ! -d ${GEOMAG_ID} ]
then
  mkdir -p ${GEOMAG_ID}
  echo "${command} : iii : creation of \${GEOMAG_ID}"
fi
# check for permission on GEOMAG_ID
if [ ! -x ${GEOMAG_ID} ]
then
 echo " eee : ${GEOMAG_ID} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
GEOMAG_OD=${outdir}
export GEOMAG_OD
unset outdir
if [ ! -d ${GEOMAG_OD} ]
then
  mkdir -p ${GEOMAG_OD}
  echo "${command} : iii : creation of \${GEOMAG_OD}"
fi
# check for permission on GEOMAG_OD
if [ ! -x ${GEOMAG_OD} ]
then
 echo " eee : ${GEOMAG_OD} not reachable"
 # nb : no exit because this file should be launched by login process
fi
if [ ! -w ${GEOMAG_OD} ]
then
 echo " eee : ${GEOMAG_OD} not writable"
 # nb : no exit because this file should be launched by login process
fi
#
# end
unset command
# nb : no exit because this file should be launched by login process
